@@ -219,7 +219,7 @@ def _pkg_get_support(pkg):
         logging.debug('_pkg_get_support %s: package has no Support header, cannot determine support level', pkg.name)
         return None
 
-    if support not in ('NFB', 'LTSB'):
+    if support not in ('NFB', 'LTSB', 'Legacy'):
         logging.warning('_pkg_get_support %s: package has invalid Support %s'
                         'header, cannot determine support level', pkg.name, support)
         return None
@@ -242,6 +242,11 @@ def _is_runtimepm_supported(pkg, alias):
         return any(fnmatch.fnmatch(alias.lower(), regex.lower()) for regex in modaliases)
 
 
+def is_wayland_session():
+    '''Check if the current session in on Wayland'''
+    return os.environ.get('WAYLAND_DISPLAY') is not None
+
+
 def _is_manual_install(pkg):
     '''Determine if the kernel module from an apt.Package is manually installed.'''
 
@@ -305,6 +310,17 @@ def _get_db_name(syspath, alias):
     return (vendor, model)
 
 
+def set_nvidia_kms(value):
+    '''Set KMS on or off for NVIDIA'''
+    nvidia_kms_file = '/lib/modprobe.d/nvidia-kms.conf'
+    kms_text = '''# This file was generated by ubuntu-drivers
+# Set value to 1 to enable modesetting, 0 to disable it
+options nvidia-drm modeset=%d\n''' % (value)
+    kms_fd = open(nvidia_kms_file, 'w')
+    kms_fd.write(kms_text)
+    kms_fd.close()
+
+
 def system_driver_packages(apt_cache=None, sys_path=None, freeonly=False, include_oem=True):
     '''Get driver packages that are available for the system.
 
